@@ -140,8 +140,12 @@ class EqualizerBar(QtWidgets.QWidget):
         self.update()
 
 
-    def setBarSolidPercent(self, f):
-        self._bar_solid_percent = float(f)
+    def setBarSolidXPercent(self, f):
+        self._x_solid_percent = float(f)
+        self.update()
+
+    def setBarSolidYPercent(self, f):
+        self._y_solid_percent = float(f)
         self.update()
 
 
