@@ -1,16 +1,10 @@
 import sys
-if 'PyQt5' in sys.modules:
-    from PyQt5 import QtCore, QtGui, QtWidgets
-    from PyQt5.QtCore import Qt
-    from PyQt5.QtCore import pyqtSignal as Signal
-    from . import resources_pyqt5
-
-else:
-    from PySide2 import QtCore, QtGui, QtWidgets
-    from PySide2.QtCore import Qt
-    from PySide2.QtCore import Signal
-    from . import resources_pyside2
+import os
+from qtpy import QtCore, QtGui, QtWidgets
+from qtpy.QtCore import Qt
+from qtpy.QtCore import Signal
 
+folder = os.path.dirname(__file__)
 
 class PasswordEdit(QtWidgets.QLineEdit):
     """
@@ -21,15 +15,15 @@ class PasswordEdit(QtWidgets.QLineEdit):
     def __init__(self, show_visibility=True, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.visibleIcon = QtGui.QIcon(":/icons/eye.svg")
-        self.hiddenIcon = QtGui.QIcon(":/icons/hidden.svg")
+        self.visibleIcon = QtGui.QIcon(os.path.join(folder, "eye.svg"))
+        self.hiddenIcon = QtGui.QIcon(os.path.join(folder, "hidden.svg"))
 
         self.setEchoMode(QtWidgets.QLineEdit.Password)
-        
+
         if show_visibility:
             # Add the password hide/shown toggle at the end of the edit box.
             self.togglepasswordAction = self.addAction(
-                self.visibleIcon, 
+                self.visibleIcon,
                 QtWidgets.QLineEdit.TrailingPosition
             )
             self.togglepasswordAction.triggered.connect(self.on_toggle_password_Action)
